.. _templating:

Templating
==========

Templating has been purposely left out of pydash. Having a custom templating engine was never a goal of pydash even though Lodash includes one. There already exist many mature and battle-tested templating engines like `Jinja2 <http://jinja2.pocoo.org/>`_ and `Mako <http://www.makotemplates.org/>`_ which are better suited to handling templating needs. However, if there was ever a strong request/justification for having templating in pydash (or a pull-request implementing it), then this decision could be re-evaluated.
